import { compact } from '../../util/array.js';
import { getPackageName } from '../../util/modules.js';
export const resolvePluginPackageName = (pluginName) => {
    return pluginName.startsWith('@')
        ? pluginName.includes('/')
            ? pluginName
            : `${pluginName}/eslint-plugin`
        : `eslint-plugin-${pluginName}`;
};
export const customResolvePluginPackageNames = (extend) => {
    if (extend.includes('/node_modules/'))
        return getPackageName(extend);
    if (extend.startsWith('/') || extend.startsWith('.'))
        return;
    if (extend.includes(':')) {
        const pluginName = extend.replace(/^plugin:/, '').replace(/(\/|:).+$/, '');
        if (pluginName === 'eslint')
            return;
        return resolvePluginPackageName(pluginName);
    }
    return extend.includes('eslint') ? getPackageName(extend) : resolvePluginPackageName(extend);
};
const getImportPluginDependencies = (settings) => {
    const knownKeys = ['typescript'];
    if (Array.isArray(settings))
        return [];
    return Object.keys(settings)
        .filter(key => key !== 'node')
        .map(key => (knownKeys.includes(key) ? `eslint-import-resolver-${key}` : key));
};
export const getDependenciesFromSettings = (settings = {}) => {
    return compact(Object.entries(settings).reduce((packageNames, [settingKey, settings]) => {
        if (/^import\/(parsers|resolvers)?/.test(settingKey)) {
            return [...packageNames, ...getImportPluginDependencies(settings)];
        }
        return packageNames;
    }, []));
};
